## Key Backup

It's very important you backup your encryption keys and Mailpile passphrase. If you lose either you will be unable to access your Mailpile or decrypt emails and attachments.

There are a few ways you can back up these crucial security aspects depending on your level of technical knowledge.

Backup Keys Now
{#

## Data Backup

Would you like to backup your data with one of the following cloud sync solutions

{{_("Back")}}
#}